#! /usr/bin/env node
import { program } from 'commander';
import spawn from 'cross-spawn';
import { loadEnv } from './index.mjs';
import '@next/env';
import 'path';

const name = "next-env-cmd";
const version = "0.3.0";
const description = "Load .env files using @next/env module";

const fullDescription = `${description}.

Examples:
  $ next-env-cmd node start.js          # load .env files in CWD
  $ next-env-cmd -d ~/ node start.js    # load .env files in ~/
  $ nexenv -p ../ node start.js         # alias shorthand command`;
program.name(name).version(version, "-v, --version").description(fullDescription).usage("[options] <command> [...args]").option(
  "-d, --dir [path]",
  "Custom env directory path",
  "./"
).option(
  "-p, --parent [path]",
  "Parent env directory path to be merged as defaults"
).option(
  "--production",
  "Forcely load production env files"
).allowUnknownOption(true).parse(process.argv);
const opts = program.opts();
const args = program.args;
loadEnv(opts);
const ps = spawn(args[0], args.slice(1), { stdio: "inherit" });
ps.on("close", (status) => process.exit(status || void 0));
process.on("SIGTERM", () => ps.kill());
